#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright 2018 Silvio Peroni (essepuntato@gmail.com)
# 
# Permission to use, copy, modify, and/or distribute this software for any purpose 
# with or without fee is hereby granted, provided that the above copyright notice 
# and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH 
# REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND 
# FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, 
# OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, 
# DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS 
# ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

import numpy as np
import pandas as pd
import scipy.stats as stats
import matplotlib.pyplot as plt
import random
import math
from os.path import dirname, sep, basename
from csv import DictReader


def get_data(file_path):
    with open(file_path) as f:
        r = DictReader(f)

        sample_means = []
        intervals = []
        categories = []
        short_categories = []
        mean = None
        for row in r:
            cur_cat = row["category"]
            if cur_cat == "ALL":
                mean = float(row["diff"])
            else:
                sample_means.append(float(row["diff"]))
                intervals.append((float(row["ci-high"]), float(row["ci-low"])))
                categories.append(cur_cat)
                s_cat = cur_cat.split(" ")
                short_cat = ""
                if len(s_cat) == 1:
                    short_cat = s_cat[0][:3]
                else:
                    for token in s_cat:
                        short_cat += token.upper()[0]
                short_categories.append(short_cat)
    return sample_means, intervals, categories, short_categories, mean

sc_type = "author"
files = (
    "../evaluation/%s-self-citations/%s-self-citations-1959-2016.csv" % (sc_type, sc_type),
    "../evaluation/%s-self-citations/%s-self-citations-2009-2016.csv" % (sc_type, sc_type)
)

sample_means_1, intervals_1, categories_1, short_categories_1, mean_1 = get_data(files[0])
sample_means_2, intervals_2, categories_2, short_categories_2, mean_2 = get_data(files[1])

plt.figure(figsize=(14, 7))
plt.subplots_adjust(left=0.30, right=0.98)

plt.subplot(121)
plt.errorbar(y=list(reversed(categories_1)),
             x=list(reversed(sample_means_1)),
             xerr=[(top-bot)/2 for top,bot in list(reversed(intervals_1))],
             fmt='o', capsize=3, elinewidth=1.0, ecolor="black", color="black")
plt.suptitle('%s Self-Citations' % sc_type.replace("-", " ").title(), fontsize=16)
plt.title('article published from 1959 to 2016')

plt.vlines(ymin=0, ymax=len(sample_means_1) - 1,
           x=(0, mean_1),
           linewidth=1.0,
           color=("red", "blue"),
           linestyles="dashed")

plt.subplot(122)
plt.errorbar(y=list(reversed(short_categories_2)),
             x=list(reversed(sample_means_2)),
             xerr=[(top - bot) / 2 for top, bot in list(reversed(intervals_2))],
             fmt='o', capsize=3, elinewidth=1.0, ecolor="black", color="black")

plt.title('article published from 2009 to 2016')

plt.vlines(ymin=0, ymax=len(sample_means_2) - 1,
           x=(0, mean_2),
           linewidth=1.0,
           color=("red", "blue"),
           linestyles="dashed")

plt.savefig(dirname(files[0]) + sep + basename(files[0]).split("-self-citations", 1)[0] + ".png", dpi=300)
